@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*)
+ *)
 
 (**
    Cache.
@@ -34,11 +34,13 @@
    @author Raphaël Proust (adding timers)
 *)
 
-module Make :
-  functor (A : sig type key type value end) ->
-  sig
-
-    (** [new cache finder ?timer size] creates a cache object where [finder]
+module Make : functor
+  (A : sig
+     type key
+     type value
+   end)
+  -> sig
+  (** [new cache finder ?timer size] creates a cache object where [finder]
         is the function responsible for retrieving non-cached data, [timer]
         (if any) is the life span of cached values (in seconds) (values in the
         cache are removed after their time is up) and [size] is the upper
@@ -51,30 +53,29 @@ module Make :
         Using [timer] allow one to create a cache
         bounded both in space and time. It is to be noted that real lifespan
         of values is always slightly greater than [timer]. *)
-    class cache : (A.key -> A.value Lwt.t) -> ?timer:float -> int ->
-      object
-
-        (** Find the cached value associated to the key, or binds this
+  class cache :
+    (A.key -> A.value Lwt.t)
+    -> ?timer:float
+    -> int
+    -> object
+         method find : A.key -> A.value Lwt.t
+         (** Find the cached value associated to the key, or binds this
             value in the cache using the function [finder] passed as argument
             to [create], and returns this value *)
-        method find : A.key -> A.value Lwt.t
 
-        (** Find the cached value associated to the key. Raises [Not_found]
+         method find_in_cache : A.key -> A.value
+         (** Find the cached value associated to the key. Raises [Not_found]
             if the key is not present in the cache *)
-        method find_in_cache : A.key -> A.value
 
-        method remove : A.key -> unit
-        method add : A.key -> A.value -> unit
-        method clear : unit -> unit
-        method size : int
-      end
-  end
+         method remove : A.key -> unit
+         method add : A.key -> A.value -> unit
+         method clear : unit -> unit
+         method size : int
+       end
+end
 
-
-(** Clear the contents of all the existing caches *)
 val clear_all_caches : unit -> unit
-
-
+(** Clear the contents of all the existing caches *)
 
 (** Doubly-linked lists with maximum number of entries,
     and (possibly) limited lifespan for entries. *)
@@ -82,81 +83,81 @@ module Dlist : sig
   type 'a t
   type 'a node
 
+  val create : ?timer:float -> int -> 'a t
   (** Create a dlist. It takes the maximum length of the list as
       parameter. The optional [?timer] parameter sets a maximum
       lifetime for elements (in seconds). *)
-  val create : ?timer:float -> int -> 'a t
 
+  val add : 'a -> 'a t -> 'a option
   (** Adds an element to the list,
       and possibly returns the element that has been removed if the maximum
       size was exceeded. *)
-  val add : 'a -> 'a t -> 'a option
 
+  val remove : 'a node -> unit
   (** Removes an element from its list.
       If it is not in a list, it does nothing.
       If it is in a list, it calls the finaliser, then removes the element.
       If the finaliser fails with an exception,
       the element is removed and the exception is raised again.
   *)
-  val remove : 'a node -> unit
 
+  val up : 'a node -> unit
   (** Removes the element from its list without finalising,
       then adds it as newest. *)
-  val up : 'a node -> unit
 
   val newest : 'a t -> 'a node option
   val oldest : 'a t -> 'a node option
-
   val size : 'a t -> int
   val maxsize : 'a t -> int
   val value : 'a node -> 'a
 
-  (** returns the timer of the Dlist *)
   val get_timer : 'a t -> float option
+  (** returns the timer of the Dlist *)
 
-  (** The list to which the node belongs *)
   val list_of : 'a node -> 'a t option
+  (** The list to which the node belongs *)
 
+  val remove_n_oldest : 'a t -> int -> 'a list
   (** remove the n oldest values (or less if the list is not long enough) ;
       returns the list of removed values *)
-  val remove_n_oldest : 'a t -> int -> 'a list
 
+  val fold : ('b -> 'a -> 'b) -> 'b -> 'a t -> 'b
   (** fold over the elements from the cache starting from the newest
       to the oldest *)
-  val fold : ('b -> 'a -> 'b) -> 'b -> 'a t -> 'b
 
+  val fold_back : ('b -> 'a -> 'b) -> 'b -> 'a t -> 'b
   (** fold over the elements from the cache starting from the oldest
       to the newest *)
-  val fold_back : ('b -> 'a -> 'b) -> 'b -> 'a t -> 'b
 
-  (** lwt version of fold *)
   val lwt_fold : ('b -> 'a -> 'b Lwt.t) -> 'b -> 'a t -> 'b Lwt.t
+  (** lwt version of fold *)
 
-  (** lwt version of fold_back *)
   val lwt_fold_back : ('b -> 'a -> 'b Lwt.t) -> 'b -> 'a t -> 'b Lwt.t
+  (** lwt version of fold_back *)
 
+  val move : 'a node -> 'a t -> 'a option
   (** Move a node from one dlist to another one, without finalizing.
       If one value is removed from the destination list (because its
       maximum size is reached), it is returned (after finalisation). *)
-  val move : 'a node -> 'a t -> 'a option
 
+  val set_maxsize : 'a t -> int -> 'a list
   (** change the maximum size ;
       returns the list of removed values, if any.
   *)
-  val set_maxsize : 'a t -> int -> 'a list
 
+  val set_finaliser_before : ('a node -> unit) -> 'a t -> unit
   (** set a function to be called automatically on a piece of data
       just before it disappears from the list
       (either by explicit removal or because the maximum size is exceeded) *)
-  val set_finaliser_before : ('a node -> unit) -> 'a t -> unit
-  val get_finaliser_before : 'a t -> ('a node -> unit)
+
+  val get_finaliser_before : 'a t -> 'a node -> unit
   val add_finaliser_before : ('a node -> unit) -> 'a t -> unit
 
-
+  val set_finaliser_after : ('a node -> unit) -> 'a t -> unit
   (** set a function to be called automatically on a piece of data
       just after it disappears from the list
       (either by explicit removal or because the maximum size is exceeded) *)
-  val set_finaliser_after : ('a node -> unit) -> 'a t -> unit
-  val get_finaliser_after : 'a t -> ('a node -> unit)
+
+  val get_finaliser_after : 'a t -> 'a node -> unit
   val add_finaliser_after : ('a node -> unit) -> 'a t -> unit
 end
